==> mono_1.1.8.3.orig.tar.gz: mono-1.1.8.3/mcs/class/System.Design/System.Web.UI.Design.WebControls/CalendarAutoFormatDialog.cs <==

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
/**
 * Namespace:   System.Web.UI.Design.WebControls
 * Class:       CalendarAutoFormatDialog
 *
 * Author:      Gaurav Vaish
 * Maintainer:  gvaish_mono@lycos.com
 *
 * (C) Gaurav Vaish (2002)
 */

using System;
using System.Web;
using System.Web.UI.WebControls;
using System.Windows.Forms;

namespace System.Web.UI.Design.WebControls
{
	public class CalendarAutoFormatDialog : Form
	{
		private Calendar calendar;
		private bool     activated;

		public CalendarAutoFormatDialog(Calendar calendar) : base()
		{
			this.calendar  = calendar;
			this.activated = false;
			this.InitializeCalendar();
		}

		[MonoTODO]
		private void InitializeCalendar()
		{
			// Load various WC-schemes.
			throw new NotImplementedException();
		}

		[MonoTODO]
		protected void OnActivated(object source, EventArgs e)
		{
			throw new NotImplementedException();
		}
	}
}

==> mono_1.2.6+dfsg.orig.tar.gz: mono-1.2.6+dfsg/mcs/class/System.Design/System.Web.UI.Design.WebControls/CalendarAutoFormatDialog.cs <==
//
// System.Web.UI.Design.WebControls.CalendarAutoFormatDialog.cs
//
// Author: Duncan Mak (duncan@novell.com)
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.Windows.Forms;
using System.Windows.Forms.Design;
using System.Web.UI.WebControls;

namespace System.Web.UI.Design.WebControls {

	public class CalendarAutoFormatDialog : Form
	{
		public CalendarAutoFormatDialog (Calendar calendar)
		{
			throw new NotImplementedException ();
		}

		protected void OnDelayLoadActions ()
		{
			throw new NotImplementedException ();
		}

		protected void OnActivated (object source, EventArgs e)
		{
			throw new NotImplementedException ();
		}

		protected void OnOKClicked (object source, EventArgs e)
		{
			throw new NotImplementedException (); 
		}

		protected void OnSelChangedScheme (object source, EventArgs e)
		{
			throw new NotImplementedException ();
		}
	}
}
